AgentEventStream

Struct AgentEventStream 

pub struct AgentEventStream { /* private fields */ }
High-level typed event stream for a single agent run.

AgentEventStream owns a StreamBroadcaster and exposes named emit_* helpers so that agent loop code does not need to construct AgentEvent variants directly.

use llm_agent_runtime::streaming::{AgentEventStream, StreamBroadcaster};

let stream = AgentEventStream::new(64)?;
let mut rx = stream.broadcaster().subscribe();

stream.emit_thought("I should search the web.")?;
stream.emit_action("search", r#"{"q":"Rust"}"#)?;
stream.emit_observation("Rust is a systems language.")?;
stream.emit_result("The answer is: Rust.")?;

Implementations

Source

impl AgentEventStream

pub fn new(capacity: usize) -> Result<Self, AgentRuntimeError>

Create a new stream with a broadcast channel of the given capacity.

Errors

Returns Err if capacity is zero.

pub fn broadcaster(&self) -> &StreamBroadcaster

Borrow the underlying StreamBroadcaster (e.g. to create additional subscribers).

pub fn emit_thought( &self, thought: impl Into<String>, ) -> Result<usize, AgentRuntimeError>

Emit a Thought event.

pub fn emit_action( &self, tool: impl Into<String>, input: impl Into<String>, ) -> Result<usize, AgentRuntimeError>

Emit an Action event.

pub fn emit_observation( &self, observation: impl Into<String>, ) -> Result<usize, AgentRuntimeError>

Emit an Observation event.

pub fn emit_result( &self, result: impl Into<String>, ) -> Result<usize, AgentRuntimeError>

Emit a Result event.

pub fn emit_error( &self, error: impl Into<String>, ) -> Result<usize, AgentRuntimeError>

Emit an Error event.

pub fn receiver_count(&self) -> usize

Return the number of active subscribers.